#####################################################################
#Sloan Neutral model script
# example of Bateria S18 / Cabernet Sauvignon Cultivar
############################CS-Bacteria-##############################


####### Part1-Neutral model calculation ####
library(dplyr)
source("Neutral model.r")

#source of  microbial communities  (total dataset of a given cultivar):S18/J19/S19 dataset of Bacteria/CS
metacommunity = read.csv(file ="matrix_Bacteria_rar8500_CS.csv" ,header=TRUE,sep=",",row.names = 1)
metacommunity[1:10,1:10]

metacommunity = t(metacommunity)

design = read.csv(file ="design_BacteriaCS_NeutralMod.csv" ,header=TRUE,row.names=1,sep=",")
head(design)

#############BACTS18 CS################
aa=design[which(design$rotation=="S18"),]
aa
bb=aa$sample

comun=metacommunity[bb,]

Neutral.fit(spp=comun, pool=metacommunity, stats=TRUE)
neu <- Neutral.fit(spp=comun, pool=metacommunity, stats=FALSE)
neu <- transform(neu, plog = log10(p))
neu$OTU<-rownames(neu)
up<-filter(neu,freq>pred.upr)
up$class<-"Abo"
lw<-filter(neu,freq<pred.lwr)
lw$class<-"Bel"
mid<-filter(neu,pred.lwr<=freq&freq<=pred.upr)
mid$class<-"Neu"
plot.data=merge(up,lw,all=T)
plot.data=merge(plot.data,mid,all=T)

write.table(plot.data,file="3B_S18CS.csv",sep = ",",row.names=TRUE)

p1=ggplot(plot.data)+geom_point(aes(x=plog,y=freq,colour=class),alpha=0.8,size=2)+
  geom_line(aes(x=plog,y=freq.pred),colour="#1E90FF",size=1)+
  geom_line(aes(x=plog,y=pred.upr),colour="#1E90FF",size=1,linetype="dashed")+
  geom_line(aes(x=plog,y=pred.lwr),colour="#1E90FF",size=1,linetype="dashed")+
  labs(x="Mean relative abundance (log10)",y="Occurrence frequency")+
  scale_colour_manual(values=c("#FFD166","#06D6A0","#8D99AE"))+
  labs(title = "Bact S18")+
  theme_bw()+theme(panel.grid.major = element_blank(),panel.grid.minor = element_blank())+guides(colour=FALSE)
p1
####Redo 14-44 lines of code，but Notice that line 15 changes the condition,Line 34 changes the name of the output file,
###In line 36, P1 is successively changed to P2, P3, and P4 and line 42 changes the lable.

library(ggpubr)
pdf("neutral model total.pdf",width=10,height=10)
ggarrange(p1,p2,p3, ncol=2,nrow=2)
dev.off()
###


####### Part2-Neutral model relative composition####
library(reshape2)
library(ggplot2)
library(vegan)
OTU = read.csv(file ="matrix_Bacteria_rar8500_CS.csv" ,header=TRUE,sep=",",row.names = 1)
OTU_t=t(OTU)
OTU_t[1:10,1:10]
design = read.csv(file ="design_BacteriaCS_NeutralMod.csv" ,header=TRUE,sep=",")


#############BACTS18 CS################
model = read.csv(file ="3B_S18CS.csv",header=TRUE,row.names=1,sep=",")
head(model)


aa=design[which(design$rotation=="S18"),]
aa
bb=aa$sample
bb
OTU1=OTU_t[bb,]
OTU1 =  as.data.frame(colMeans(OTU1))
OTU1=as.matrix(OTU1)
head(OTU1)

###  Calculation the percentage of the Above, Below and neutral part #
library("questionr")
a=cprop(OTU1)###Column percentages##
a
OTU2=as.data.frame(a[!rownames(a) %in% c("Total") , -which(colnames(a) %in% c("Ensemble"))])##
head(OTU2)
OTU2$OTU=rownames(OTU2)
OTU3=merge(model[,c("OTU","class")],OTU2,by.x="OTU",all= T)
head(OTU3)
OTU4=aggregate(OTU3[,(-1:-2)],list(OTU3$class),sum)
head(OTU4)

label=c(rep("S18", 3)) 
OTU5=data.frame(OTU4, label)

p1 = ggplot(OTU5, aes(x=label, y = x, fill = Group.1 )) + 
  geom_bar(stat = "identity",position="stack",width=0.8)+ 
  
  xlab("")+
  ylab("BactS18 cumulative relative abundance")+
  theme_classic()+
  theme(axis.text = element_text(size = 12), axis.title = element_text(size = 13)) +
  theme(legend.text = element_text(size = 11))+
  scale_fill_manual(values =rev(c("Abo"="#FFD166","Bel"="#06D6A0","Neu"="#8D99AE"))) +
  theme(panel.grid = element_blank(), panel.background = element_rect(color = 'black', fill = 'transparent')) +
  theme(legend.title = element_blank())
p1
####redo the code of lines 65-104，but notice change the condition of line 66,70,91.
#In line 94,change the p1 to p2,p3,p4 successively

library(ggpubr)
pdf("neutal model relative coposition.pdf",width=6,height=10)
ggarrange(p1,p2,p3, ncol=2,nrow=2)
dev.off()



###########Part3-Class level composition
OTU = read.csv(file ="matrix_Bacteria_rar8500_CS.csv" ,header=TRUE,sep=",",row.names = 1)
OTU[1:10,1:10]
OTU_t=t(OTU)
OTU_t[1:10,1:10]
design = read.csv(file ="design_BacteriaCS_NeutralMod.csv" ,header=TRUE,sep=",")


#############BACTS18 CS################
aa=design[which(design$rotation=="S18"),]
aa
bb=aa$sample
OTU1=as.data.frame(OTU_t[bb,])
OTU1[1:10,1:10]
OTU2=as.data.frame(t(OTU1))
OTU2$OTU=rownames(OTU2)

model = read.csv(file ="3B_S18CS.csv",header=TRUE,row.names=1,sep=",")

head(model)

OTU3=merge(model[,c("OTU","class")],OTU2,by.x="OTU",all= F)
OTU3=rename(OTU3,"#OTU"=OTU)
OTU3[1:10,1:10]
Abo=OTU3[which(OTU3$class=="Abo"),]
Bel=OTU3[which(OTU3$class=="Bel"),]
Neu=OTU3[which(OTU3$class=="Neu"),]

Abo=Abo[which(rowSums(Abo[,-1:-2]) > 0),]
Bel=Bel[which(rowSums(Bel[,-1:-2]) > 0),]
Neu=Neu[which(rowSums(Neu[,-1:-2]) > 0),]

Abo=Abo[,-2]
Bel=Bel[,-2]
Neu=Neu[,-2]


write.table(Abo,"6B_Abo_S18CS.txt",sep ='\t',quote = FALSE,row.names = F,col.names = T)
write.table(Bel,"6B_Bel_S18CS.txt",sep ='\t',quote = FALSE,row.names = F,col.names = T)
write.table(Neu,"6B_Neu_S18CS.txt",sep ='\t',quote = FALSE,row.names = F,col.names = T)




####### Class level composition####
library(reshape2)
library(ggplot2)
library(vegan)
library(dplyr)

############BACT S18CS_ABOVE###############################"


OTU <- read.table('6B_Abo_S18CS.txt', sep='\t', header=T, comment.char='', check.names=F)
#OTU <- read.table('6B_Bel_S18CS.txt', sep='\t', header=T, comment.char='', check.names=F)
#OTU <- read.table('6B_Neu_S18CS.txt', sep='\t', header=T, comment.char='', check.names=F)

OTU

annotation = read.csv(file ="Annotation_volet1-Bact_rar8500woOutlier_CS.csv" ,header=TRUE, row.names = 1)
annotation=annotation[,(1:6)]#car putain de bug avec excel et les virgule
annotation$"#OTU"=rownames(annotation)

spe1=merge(annotation,OTU,by.x="#OTU",all=F)
spe1

Phylum=aggregate(spe1[,(-1:-7)],list(spe1$Class),sum)



rownames(Phylum)=Phylum$Group.1
Phylum=as.matrix(Phylum[,-1])


###  Calculation  #
library("questionr")
a=cprop(Phylum)###Column percentages##
head(a)
OTU2=as.data.frame.array(a[!rownames(a) %in% c("Total") , -which(colnames(a) %in% c("Ensemble"))])##删除求相对丰度生成的总行和列Supprimez le total des lignes et des colonnes générées en recherchant l'abondance relative
head(OTU2)

OTU3 <- OTU2[which(rownames(OTU2)!="unknow"),]##
# Decreased sort by abundance
OTU4 = as.data.frame(OTU3[(order(-rowSums(OTU3))), ])
# Calculate average relative abundance for each group
OTU5 =  as.data.frame(rowMeans(OTU4))
OTU5$Phylum=rownames(OTU5)
head(OTU5)
# Filter Top 9 , and other group into Low abundance
other = as.data.frame(sum(OTU5[10:dim(OTU5)[1],1 ]))
other$Phylum=rownames(other)
OTU6 = OTU5[1:(10 - 1), ]
library(dplyr)
OTU6=rename(OTU6,"Mean"='rowMeans(OTU4)')
other=rename(other,"Mean"=`sum(OTU5[10:dim(OTU5)[1], 1])`)

mean_sort = rbind(OTU6,other)
rownames(mean_sort)[10] = c("Low abundance")


# data melt for ggplot2
mean_sort$Phylum = rownames(mean_sort)
data_all = as.data.frame(melt(mean_sort, id.vars=c("Phylum")))
# Set taxonomy order by abundance, default by alphabet##
data_all$Phylum  = factor(data_all$Phylum, levels=rownames(mean_sort))

tax=data_all[,1]
tax=as.data.frame(tax)
rownames(tax)<-rownames(data_all)
tax$value<-as.numeric(data_all$value)
tax$variable<-as.character(data_all$variable)
data_all=tax

p1 = ggplot(data_all, aes(x=variable, y = value, fill = tax )) + 
  geom_bar(stat = "identity",position="fill", width=0.8)+ 
  scale_y_continuous(labels = scales::percent) + 
  
  xlab("BactS18CS-ABOVE")+
  
  ylab("Relative Abundance(%)")+ theme_classic()+
  theme(axis.text = element_text(size = 12), axis.title = element_text(size = 13)) +
  theme(legend.text = element_text(size = 11))+
   scale_fill_manual(values =rev(c("Bdellovibrionia"="#3C3A8D","Acidobacteria"="#BEBADA","Acidobacteriae"="#BEBADA","Actinobacteria"="#8DD3C7",
                                  "Armatimonadetes"="#000000","Bacteroidia"="#44A8DB","Polyangia"="#57B78C",
                                  "Thermoleophilia"="#EA711B","Multi-affiliation"="#CECE05",
                                  "Chlamydiae"="#AA9953","Chloroflexi"="#093A3A",
                                  "Cyanobacteria"="#02759E","Deinococcus-Thermus"="#3A398C","Firmicutes"="#74B662",
                                  "Gemmatimonadetes"="#FFBB78FF","Latescibacteria"="#B53C0D", "Fibrobacteria"="#C49C94FF",
                                  "Nitrospirae"="#03F1F7","Myxococcia"="#F962C3","Proteobacteria"="#F95A5A",
                                  "Tenericutes"="#0808B7","Verrucomicrobia"="#144404","Low abundance"="#cccccc",
                                  "unknow"="#9E7C61","Thermoanaerobaculia"="#D3C13C","Alphaproteobacteria"="#FFFFB3","Bacilli"="#FB8072","Betaproteobacteria"="#80B1D3","Cytophagia"="#B3DE69","Deltaproteobacteria"="#BC80BD","Gammaproteobacteria"="#FCCDE5","Flavobacteriia"="#FF0000","Sphingobacteriia"="#CCEBC5","Unsigned"="#80734C"))) +
  theme(panel.grid = element_blank(), panel.background = element_rect(color = 'black', fill = 'transparent')) +
  theme(legend.title = element_blank())

p1

############BACT S18CS_BELOW###############################"

#OTU <- read.table('6B_Abo_S18CS.txt', sep='\t', header=T, comment.char='', check.names=F)
OTU <- read.table('6B_Bel_S18CS.txt', sep='\t', header=T, comment.char='', check.names=F)
#OTU <- read.table('6B_Neu_S18CS.txt', sep='\t', header=T, comment.char='', check.names=F)

OTU

annotation = read.csv(file ="Annotation_volet1-Bact_rar8500woOutlier_CS.csv" ,header=TRUE, row.names = 1)
annotation=annotation[,(1:6)]#car putain de bug avec excel et les virgule
annotation$"#OTU"=rownames(annotation)

spe1=merge(annotation,OTU,by.x="#OTU",all=F)
spe1

Phylum=aggregate(spe1[,(-1:-7)],list(spe1$Class),sum)



rownames(Phylum)=Phylum$Group.1
Phylum=as.matrix(Phylum[,-1])


###  Calculation  #
library("questionr")
a=cprop(Phylum)###Column percentages##
head(a)
OTU2=as.data.frame.array(a[!rownames(a) %in% c("Total") , -which(colnames(a) %in% c("Ensemble"))])##删除求相对丰度生成的总行和列Supprimez le total des lignes et des colonnes générées en recherchant l'abondance relative
head(OTU2)

OTU3 <- OTU2[which(rownames(OTU2)!="unknow"),]##
# Decreased sort by abundance
OTU4 = as.data.frame(OTU3[(order(-rowSums(OTU3))), ])
# Calculate average relative abundance for each group
OTU5 =  as.data.frame(rowMeans(OTU4))
OTU5$Phylum=rownames(OTU5)
head(OTU5)
# Filter Top 9 , and other group into Low abundance
other = as.data.frame(sum(OTU5[10:dim(OTU5)[1],1 ]))
other$Phylum=rownames(other)
OTU6 = OTU5[1:(10 - 1), ]
library(dplyr)
OTU6=rename(OTU6,"Mean"='rowMeans(OTU4)')
other=rename(other,"Mean"=`sum(OTU5[10:dim(OTU5)[1], 1])`)

mean_sort = rbind(OTU6,other)
rownames(mean_sort)[10] = c("Low abundance")


# data melt for ggplot2
mean_sort$Phylum = rownames(mean_sort)
data_all = as.data.frame(melt(mean_sort, id.vars=c("Phylum")))
# Set taxonomy order by abundance, default by alphabet##
data_all$Phylum  = factor(data_all$Phylum, levels=rownames(mean_sort))

tax=data_all[,1]
tax=as.data.frame(tax)
rownames(tax)<-rownames(data_all)
tax$value<-as.numeric(data_all$value)
tax$variable<-as.character(data_all$variable)
data_all=tax

p2 = ggplot(data_all, aes(x=variable, y = value, fill = tax )) + 
  geom_bar(stat = "identity",position="fill", width=0.8)+ 
  scale_y_continuous(labels = scales::percent) + 
  
  xlab("BactS18CS-BELOW")+
  
  ylab("Relative Abundance(%)")+ theme_classic()+
  theme(axis.text = element_text(size = 12), axis.title = element_text(size = 13)) +
  theme(legend.text = element_text(size = 11))+
   scale_fill_manual(values =rev(c("Bdellovibrionia"="#3C3A8D","Acidobacteria"="#BEBADA","Acidobacteriae"="#BEBADA","Actinobacteria"="#8DD3C7",
                                  "Armatimonadetes"="#000000","Bacteroidia"="#44A8DB","Polyangia"="#57B78C",
                                  "Thermoleophilia"="#EA711B","Multi-affiliation"="#CECE05",
                                  "Chlamydiae"="#AA9953","Chloroflexi"="#093A3A",
                                  "Cyanobacteria"="#02759E","Deinococcus-Thermus"="#3A398C","Firmicutes"="#74B662",
                                  "Gemmatimonadetes"="#FFBB78FF","Latescibacteria"="#B53C0D", "Fibrobacteria"="#C49C94FF",
                                  "Nitrospirae"="#03F1F7","Myxococcia"="#F962C3","Proteobacteria"="#F95A5A",
                                  "Tenericutes"="#0808B7","Verrucomicrobia"="#144404","Low abundance"="#cccccc",
                                  "unknow"="#9E7C61","Thermoanaerobaculia"="#D3C13C","Alphaproteobacteria"="#FFFFB3","Bacilli"="#FB8072","Betaproteobacteria"="#80B1D3","Cytophagia"="#B3DE69","Deltaproteobacteria"="#BC80BD","Gammaproteobacteria"="#FCCDE5","Flavobacteriia"="#FF0000","Sphingobacteriia"="#CCEBC5","Unsigned"="#80734C"))) +
  theme(panel.grid = element_blank(), panel.background = element_rect(color = 'black', fill = 'transparent')) +
  theme(legend.title = element_blank())

p2

############BACT S18CS_NEUTRAL###############################"

#OTU <- read.table('6B_Abo_S18CS.txt', sep='\t', header=T, comment.char='', check.names=F)
#OTU <- read.table('6B_Bel_S18CS.txt', sep='\t', header=T, comment.char='', check.names=F)
OTU <- read.table('6B_Neu_S18CS.txt', sep='\t', header=T, comment.char='', check.names=F)

OTU

  annotation = read.csv(file ="Annotation_volet1-Bact_rar8500woOutlier_CS.csv" ,header=TRUE, row.names = 1)
  annotation=annotation[,(1:6)]#car putain de bug avec excel et les virgule
annotation$"#OTU"=rownames(annotation)

spe1=merge(annotation,OTU,by.x="#OTU",all=F)
spe1

Phylum=aggregate(spe1[,(-1:-7)],list(spe1$Class),sum)



rownames(Phylum)=Phylum$Group.1
Phylum=as.matrix(Phylum[,-1])


###  Calculation  #
library("questionr")
a=cprop(Phylum)###Column percentages##
head(a)
OTU2=as.data.frame.array(a[!rownames(a) %in% c("Total") , -which(colnames(a) %in% c("Ensemble"))])##删除求相对丰度生成的总行和列Supprimez le total des lignes et des colonnes générées en recherchant l'abondance relative
head(OTU2)

OTU3 <- OTU2[which(rownames(OTU2)!="unknow"),]##
# Decreased sort by abundance
OTU4 = as.data.frame(OTU3[(order(-rowSums(OTU3))), ])
# Calculate average relative abundance for each group
OTU5 =  as.data.frame(rowMeans(OTU4))
OTU5$Phylum=rownames(OTU5)
head(OTU5)
# Filter Top 9 , and other group into Low abundance
other = as.data.frame(sum(OTU5[10:dim(OTU5)[1],1 ]))
other$Phylum=rownames(other)
OTU6 = OTU5[1:(10 - 1), ]
library(dplyr)
OTU6=rename(OTU6,"Mean"='rowMeans(OTU4)')
other=rename(other,"Mean"=`sum(OTU5[10:dim(OTU5)[1], 1])`)

mean_sort = rbind(OTU6,other)
rownames(mean_sort)[10] = c("Low abundance")


# data melt for ggplot2
mean_sort$Phylum = rownames(mean_sort)
data_all = as.data.frame(melt(mean_sort, id.vars=c("Phylum")))
# Set taxonomy order by abundance, default by alphabet##
data_all$Phylum  = factor(data_all$Phylum, levels=rownames(mean_sort))

tax=data_all[,1]
tax=as.data.frame(tax)
rownames(tax)<-rownames(data_all)
tax$value<-as.numeric(data_all$value)
tax$variable<-as.character(data_all$variable)
data_all=tax

p3 = ggplot(data_all, aes(x=variable, y = value, fill = tax )) + 
  geom_bar(stat = "identity",position="fill", width=0.8)+ 
  scale_y_continuous(labels = scales::percent) + 
  
  xlab("BactS18CS-NEUTRAL")+
  
  ylab("Relative Abundance(%)")+ theme_classic()+
  theme(axis.text = element_text(size = 12), axis.title = element_text(size = 13)) +
  theme(legend.text = element_text(size = 11))+
   scale_fill_manual(values =rev(c("Bdellovibrionia"="#3C3A8D","Acidobacteria"="#BEBADA","Acidobacteriae"="#BEBADA","Actinobacteria"="#8DD3C7",
                                  "Armatimonadetes"="#000000","Bacteroidia"="#44A8DB","Polyangia"="#57B78C",
                                  "Thermoleophilia"="#EA711B","Multi-affiliation"="#CECE05",
                                  "Chlamydiae"="#AA9953","Chloroflexi"="#093A3A",
                                  "Cyanobacteria"="#02759E","Deinococcus-Thermus"="#3A398C","Firmicutes"="#74B662",
                                  "Gemmatimonadetes"="#FFBB78FF","Latescibacteria"="#B53C0D", "Fibrobacteria"="#C49C94FF",
                                  "Nitrospirae"="#03F1F7","Myxococcia"="#F962C3","Proteobacteria"="#F95A5A",
                                  "Tenericutes"="#0808B7","Verrucomicrobia"="#144404","Low abundance"="#cccccc",
                                  "unknow"="#9E7C61","Thermoanaerobaculia"="#D3C13C","Alphaproteobacteria"="#FFFFB3","Bacilli"="#FB8072","Betaproteobacteria"="#80B1D3","Cytophagia"="#B3DE69","Deltaproteobacteria"="#BC80BD","Gammaproteobacteria"="#FCCDE5","Flavobacteriia"="#FF0000","Sphingobacteriia"="#CCEBC5","Unsigned"="#80734C"))) +
  theme(panel.grid = element_blank(), panel.background = element_rect(color = 'black', fill = 'transparent')) +
  theme(legend.title = element_blank())

p3
 
#######

library(ggpubr)
pdf("class-compoosiyion.pdf",width=12,height=12)
ggarrange(p1,p2,p3, ncol=3,nrow=4)

dev.off()
##
