library(vegan)
library(RVAideMemoire)
library(Hotelling)

#####################################################################
#PCOA script: example of Bateria / Cabernet Sauvignon Cultivar --> effect of sampling date
############################CS-Bacteria##############################
#data  (contingency table & conditions)
species=read.csv("tmatrix_Bacteria_rar8500_CS.csv",h=T, sep=",", row.names = 1)

species=species[, which(colSums(species) != 0)]

write.csv(species,"tmatrix_Bacteria_rar8500_CSwoClusterneg.csv")

condition=read.csv("design_BacteriaCS_PCOA.csv",h=T, sep=",", row.names = 1,stringsAsFactors=TRUE)


# distance Matrix de distance (Hellinger transfo) - dist(): Euclidien default
mat.dist <- dist(decostand(species,method="hellinger"))

# PCoA 
PCoA <- dbrda(mat.dist~1+Condition(pied),data=condition)
MVA.synt(PCoA)
MVA.scoreplot(PCoA,fac=condition$Sampling,col=c("#000000", "#E69F00", "#56B4E9"),legend=T,drawextaxes=TRUE)

envfit(PCoA~Sampling,data=condition)
pairwise.factorfit(PCoA,condition$Sampling)

##############################################################################################################
##############################################################################################################
library(vegan)
library(RVAideMemoire)
library(Hotelling)
#####################################################################
#RDA script: example of Bateria / S18 sampling date--> effect of cultivar
############################S18 Bacteria##############################
#data  (contingency table & conditions)
species=read.csv("tmatrix_Bacteria_rar8500CSM_S18.csv",h=T, sep=",", row.names = 1)

species=species[, which(colSums(species) != 0)]

write.csv(species,"tmatrix_Bacteria_rar8500CSM_S18woClusterneg.csv")

condition=read.csv("design_BacteriaS18_RDA.csv",h=T, sep=",", row.names = 1,stringsAsFactors=TRUE)

species2 <- decostand(species,method="hellinger")


# RDA 
RDA <- rda(species2~Cultivar,data=condition)
MVA.synt(RDA)
MVA.anova(RDA)
#MVA.plot(RDA,fac=condition$Cultivar,col=1:3)
MVA.scoreplot(RDA,fac=condition$Cultivar,col=c("#009999", "#CC0033"),legend=T,drawextaxes=TRUE, main="S18: Bacterial composition between cultivars"	)
pairwise.factorfit(RDA,condition$Cultivar)
MVA.plot(RDA,"corr",arrows=FALSE,ident=FALSE)


